@@ -4,6 +4,11 @@ module Interpreter (
 , safeEval
 , withInterpreter
 , ghc
+, interpreterSupported
+
+-- exported for testing
+, ghcInfo
+, haveInterpreterKey
 ) where
 
 import           System.IO
@@ -11,6 +16,7 @@ import           System.Process
 import           System.Exit
 import           System.Directory (getPermissions, executable)
 import           Control.Monad (when, unless)
+import           Control.Applicative
 import           Control.Exception hiding (handle)
 import           Data.Char
 import           Data.List
@@ -31,15 +37,24 @@ data Interpreter = Interpreter {
   , process :: ProcessHandle
   }
 
-newInterpreter :: [String] -> IO Interpreter
-newInterpreter flags = do
+haveInterpreterKey :: String
+haveInterpreterKey = "Have interpreter"
 
+ghcInfo :: IO [(String, String)]
+ghcInfo = read <$> readProcess ghc ["--info"] []
+
+interpreterSupported :: IO Bool
+interpreterSupported = do
   -- in a perfect world this permission check should never fail, but I know of
   -- at least one case where it did..
   x <- getPermissions ghc
   unless (executable x) $ do
     fail $ ghc ++ " is not executable!"
 
+  maybe False (== "YES") . lookup haveInterpreterKey <$> ghcInfo
+
+newInterpreter :: [String] -> IO Interpreter
+newInterpreter flags = do
   (Just stdin_, Just stdout_, Nothing, processHandle ) <- createProcess $ (proc ghc myFlags) {std_in = CreatePipe, std_out = CreatePipe, std_err = Inherit}
   setMode stdin_
   setMode stdout_
@@ -88,7 +103,7 @@ closeInterpreter repl = do
   e <- waitForProcess $ process repl
   hClose $ hOut repl
 
-  when (e /= ExitSuccess) $ error $ "Interpreter exited with an error: " ++ show e 
+  when (e /= ExitSuccess) $ error $ "Interpreter exited with an error: " ++ show e
   return ()
 
 putExpression :: Interpreter -> String -> IO ()
